@@ -1,5 +1,8 @@
+pub type Element = i32;
+pub type Callback = i32;
+pub type CString = i32;
 pub use callback::{add_callback, route_callback};
-pub use cstring::cstr;
+use std::ffi::CStr;
 extern crate anymap;
 use anymap::AnyMap;
 // A global store of components to prevent deallocation
@@ -21,3 +24,12 @@ pub fn get_components<T>() -> &'static mut Vec<T> {
 pub fn get_component<T>(id: usize) -> &'static T {
     &get_components::<T>()[id]
 }
+
+pub fn cstr(s: &str) -> CString {
+    cstring::cstr(s)
+}
+
+pub fn cstr_from_raw(p: CString) -> String {
+    let s: &CStr = unsafe { CStr::from_ptr(p as *const i8) };
+    s.to_str().unwrap().to_owned()
+}
